SortedVecSet

Struct SortedVecSet 

pub struct SortedVecSet<T> { /* private fields */ }
An ordered set built on a SortedVecMap.

SortedVecSet provides a memory-efficient alternative to BTreeSet by wrapping SortedVecMap<T, ()>.

Complexity

OperationTime ComplexitySpace Complexity
new / with_capacityO(1)O(1)
contains / getO(log N)O(1)
insertO(N)O(1) amortized
removeO(N)O(1)
union / differenceO(N + M)O(1)

When to use

  • Similar to SortedVecMap, it is ideal for read-heavy, memory-constrained sets.

Implementations

Source

impl<T> SortedVecSet<T>

pub fn builder() -> SortedVecSetBuilder<T>

Returns a new builder for SortedVecSet.

pub fn builder_with_capacity(capacity: usize) -> SortedVecSetBuilder<T>

Returns a new builder for SortedVecSet with at least the specified capacity.

pub fn new() -> Self

Constructs a new, empty SortedVecSet.

pub fn capacity(&self) -> usize

Returns the number of elements the set can hold without reallocating.

pub fn with_capacity(capacity: usize) -> Self

Constructs a new, empty SortedVecSet with at least the specified capacity.

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more elements in the SortedVecSet.

pub fn shrink_to_fit(&mut self)

Shrinks the capacity of the set as much as possible.

pub fn len(&self) -> usize

Returns the number of elements in the set.

pub fn is_empty(&self) -> bool

Returns true if there are no elements in the set.

pub fn contains<Q>(&self, value: &Q) -> bool
where T: Borrow<Q> + Ord, Q: Ord + ?Sized,

Returns true if the set contains the given value.

Complexity: O(log n) time.

pub fn get<Q>(&self, value: &Q) -> Option<&T>
where T: Borrow<Q> + Ord, Q: Ord + ?Sized,

Returns a reference to the value in the set, if any, that is equal to the given value.

Complexity: O(log n) time.

pub fn insert(&mut self, value: T) -> bool
where T: Ord,

Inserts a value into the set. Returns true if the value was not already present.

Complexity: O(log n) search time, plus O(n) time to insert the element if it is not present.

pub fn remove<Q>(&mut self, value: &Q) -> bool
where T: Borrow<Q> + Ord, Q: Ord + ?Sized,

Removes a value from the set. Returns true if the value was present.

Complexity: O(log n) search time, plus O(n) time to remove the element if it is present.

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over the elements of the set, in sorted order.

pub fn range<Q, R>(&self, range: R) -> Range<'_, T>
where T: Borrow<Q> + Ord, Q: Ord + ?Sized, R: RangeBounds<Q>,

Constructs a double-ended iterator over a sub-range of elements in the set.

Complexity: O(log n) to find the start and end of the range.

pub fn union<'a>(&'a self, other: &'a Self) -> Union<'a, T>
where T: Ord,

Returns an iterator yielding elements from both sets in sorted order, without duplicates.

Complexity: O(N + M) where N is the number of elements in self and M is the number of elements in other.

pub fn difference<'a>(&'a self, other: &'a Self) -> Difference<'a, T>
where T: Ord,

Returns an iterator yielding elements in self that are not in other.

Complexity: O(N + M) where N is the number of elements in self and M is the number of elements in other.